Skip to contents

`custom_biochemical_reaction_loading` opens the custom biochemical reaction dataset (collected by James Zhan) as a tibble and return it. User can add their own biochemical reaction dataset in the same format and load it with this function.

Usage

custom_biochemical_reaction_loading()

Value

a tibble