Skip to contents

This function finds overlapping m/z and/or retention time values between two data sets.

Usage

find.Overlapping.mzs(dataA, dataB, mz.thresh = 5, time.thresh = NA)

Arguments

dataA

A feature table. The first column is considered as mz. If the second column is included (optional), it is considered as retention time.

dataB

A feature table. The first column is considered as mz. If the second column is included (optional), it is considered as retention time.

mz.thresh

The m/z threshold for matching features between two data sets. Default is 5 ppm.

time.thresh

The retention time threshold for matching features between two data sets. Default is NA (retention time is not used for matching). If this is used, the recommended input is 30 (seconds).

Value

Matrix of overlapping features with columns: index.data.A: index of overlapping m/z in dataset A mz.data.A: m/z in dataset A time.data.A: retention time in dataset A index.data.B: index of overlapping m/z in dataset B mz.data.B: m/z in dataset B time.data.B: retention time in dataset B.