find.Overlapping.mzs
find.Overlapping.mzs.RdThis function finds overlapping m/z and/or retention time values between two data sets.
Arguments
- dataA
A feature table. The first column is considered as mz. If the second column is included (optional), it is considered as retention time.
- dataB
A feature table. The first column is considered as mz. If the second column is included (optional), it is considered as retention time.
- mz.thresh
The m/z threshold for matching features between two data sets. Default is 5 ppm.
- time.thresh
The retention time threshold for matching features between two data sets. Default is NA (retention time is not used for matching). If this is used, the recommended input is 30 (seconds).